Learn R Programming

rEMM (version 1.0-7)

TRAC: TRAC: Creating an EMM from a Regular Clustering

Description

Create an EMM from a regular clustering (k-means or PAM) of sequence data.

Usage

TRAC(x, data = NULL, measure = "euclidean")

Arguments

x
a clustering object (result of kmeans or pam) or a vector with (integer) cluster assignments.
data
the data used for clustering (only used if x is a cluster assignment vector).
measure
used distance measure.

Value

  • A EMM object representing the clustering of sequence data.

Details

The order is inferred from the order in the original data set.

Examples

Run this code
data("EMMsim")

## using kmeans
cl <- kmeans(EMMsim_train, 10)
emm <- TRAC(cl)
emm
plot(emm, method = "MDS")

## using a cluster assignment vector (taken from the k-means clustering above)
x <- cl$cluster
emm <- TRAC(x, data = EMMsim_train)
emm
plot(emm, method = "MDS")

Run the code above in your browser using DataLab